@@ -8,7 +8,7 @@
 #elif !defined(PETSC_HAVE_FORTRAN_UNDERSCORE)
   #define petscsfcreateembeddedsf_ petscsfcreateembeddedsf
 #endif
-PETSC_EXTERN void petscsfcreateembeddedsf_(PetscSF *a, PetscInt *b, const PetscInt *c, PetscSF *d, PetscErrorCode *ierr)
+PETSC_EXTERN void petscsfcreateembeddedsf_(PetscSF *a, PetscInt *b, const PetscInt c[], PetscSF *d, PetscErrorCode *ierr)
 {
   PetscBool null_d = !*(void**) d ? PETSC_TRUE : PETSC_FALSE;
   CHKFORTRANNULLINTEGER(c);
